==> nimbleCarbon_0.2.5.tar.gz: nimbleCarbon/README.md <==
[![cran version](http://www.r-pkg.org/badges/version/nimbleCarbon)](https://CRAN.R-project.org/package=nimbleCarbon) 
[![development version](https://img.shields.io/badge/devel%20version-0.2.2-lightblue.svg)](https://github.com/ercrema/nimbleCarbon)
[![R-CMD-check](https://github.com/ercrema/nimbleCarbon/workflows/R-CMD-check/badge.svg)](https://github.com/ercrema/nimbleCarbon/actions)
# nimbleCarbon <img src="/logo/logo.png" align="right" />

The _nimbleCarbon_ package provides utility functions and bespoke probability distributions for the Bayesian analyses of radiocarbon dates using the [NIMBLE](https://r-nimble.org/) framework. The package is particularly suited for demographic inferences based on changing frequencies of radiocarbon dates and enables parameter estimations and model comparison for the following population growth models (see Crema and Shoda 2021 for details):

* Exponential
* Logistic
* Double-Exponential
* Exponential-Logistic
* Logistic-Exponential
* Trapezoidal
* Asymmetric Laplace

Community contributions of additional growth models and features are welcome. For more information and tutorial please check the [vignette](https://htmlpreview.github.io/?https://github.com/ercrema/nimbleCarbon/blob/main/vignettes/nimble_carbon_vignette.html).

References

Crema, E. R., & Shoda, S. (2021). [A Bayesian approach for fitting and comparing demographic growth models of radiocarbon dates: a case study on the Jomon-Yayoi transition in Kyushu (Japan)](https://doi.org/10.1371/journal.pone.0251695). PLOS ONE, 16(5), e0251695.

==> nimbleCarbon_0.2.6.tar.gz: nimbleCarbon/README.md <==
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/nimbleCarbon)](https://CRAN.R-project.org/package=nimbleCarbon)
[![development version](https://img.shields.io/badge/devel%20version-0.2.5-lightblue.svg)](https://github.com/ercrema/nimbleCarbon)
[![R-CMD-check](https://github.com/ercrema/nimbleCarbon/workflows/R-CMD-check/badge.svg)](https://github.com/ercrema/nimbleCarbon/actions)
[![](https://cranlogs.r-pkg.org/badges/grand-total/nimbleCarbon)](https://cran.r-project.org/package=nimbleCarbon)
# nimbleCarbon <img src="/logo/logo.png" align="right" />

The _nimbleCarbon_ package provides utility functions and bespoke probability distributions for the Bayesian analyses of radiocarbon dates using the [NIMBLE](https://r-nimble.org/) framework. The package is particularly suited for demographic inferences based on changing frequencies of radiocarbon dates and enables parameter estimations and model comparison for the following population growth models (see Crema and Shoda 2021 for details):

* Exponential
* Logistic
* Double-Exponential
* Exponential-Logistic
* Logistic-Exponential
* Trapezoidal
* Asymmetric Laplace

Community contributions of additional growth models and features are welcome. For more information and tutorial please check the [vignette](https://htmlpreview.github.io/?https://github.com/ercrema/nimbleCarbon/blob/main/vignettes/nimble_carbon_vignette.html).

References

Crema, E. R., & Shoda, S. (2021). [A Bayesian approach for fitting and comparing demographic growth models of radiocarbon dates: a case study on the Jomon-Yayoi transition in Kyushu (Japan)](https://doi.org/10.1371/journal.pone.0251695). PLOS ONE, 16(5), e0251695.
